The source repository for this project can be found at:

   https://opendev.org/openstack/openstackdocstheme

Pull requests submitted through GitHub are not monitored.

To start contributing to OpenStack, follow the steps in the contribution guide
to set up and use Gerrit:

   https://docs.openstack.org/contributors/code-and-documentation/quick-start.html

Bugs should be filed on Launchpad, using a theme tag:

   https://launchpad.net/openstack-doc-tools
